/**
 * Text fragment parameters as defined in https://web.dev/text-fragments/#the-full-syntax
 */
export declare class TextFragment {
    prefix: string;
    suffix: string;
    textStart: string;
    textEnd: string;
    /**
     * If textEnd is missing, it will match the entire textStart string, otherwise
     * it will return all the data from textStart to textEnd excluding prefix and suffix.
     * @param textStart Starting words
     * @param textEnd Ending words (Optional)
     * @param prefix Prefix (Optional). Must end with '-'
     * @param suffix Suffix (Optional). Must start with '-'
     */
    constructor(textStart: string, textEnd?: string, prefix?: string, suffix?: string);
    /**
     * Extracts the complete text fragment from a given plaintext source
     * @param body Text content (usually document.body.textContent)
     * @returns Entire text fragment string if found, else null
     */
    extract: (body: string) => string | null;
}
/**
 * Extracts the percent-decoded text fragments from an URL
 * @param url URL to get text fragments from
 * @returns An array of text fragments, empty if not found
 */
export declare const extractTextFragments: (url: URL | string) => TextFragment[];
/**
 * Scrape a URL to extract the text fragments inside the URL's hash
 * @param url URL to scrape and extract text fragments from
 * @param pageWaitMs If waitTillRendered is false, wait for specified milliseconds to load site
 * @param waitTillRendered (Experimental) use with dynamically loaded websites which load content using JS
 * @returns Array of text fragment contents
 */
export declare const scrapeURL: (url: URL | string, pageWaitMs?: number, waitTillRendered?: boolean) => Promise<string[]>;
